kaleo
=====

Provides a site with user to user invitations for Pinax based sites.


Documentation
-------------

Documentation can be found online at http://kaleo.readthedocs.org/.

The original announcement can be found on the Pinax Project blog at http://pinaxproject.com/blog/2011/08/31/kaleo-user-user-join-invitations/.

